#include <stdio.h>
#include <windows.h>
#include "COM-AMP5.h"

// handle a possible error:
static int Error (int code)
	{
	printf ("%s\n", COM_AMP5_ErrorMessage (0));
	return code;
	}

int main (int argc, char * argv[])
	{
	if (argc != 2)
		{
		printf ("The number of the COM port must be specified!\n");
		return -1;
		}
	// check the DLL version:
	WORD DLL_Version = COM_AMP5_Version();
	if ((DLL_Version & 0xFF00) != 0x0100)
		{
		printf ("Wrong DLL Version: expected 1.x, found %d.%02d\n",
			DLL_Version / 0x100, DLL_Version & 0xFF);
		return 1;
		}

	// open the port 0:
	WORD COMNumber;
	sscanf (argv[1], "%hu", &COMNumber);
	if (COM_AMP5_Open (0, COMNumber))
		return Error (2); // handle a possible error

	// Get device hardware capabilities:
	BYTE ChannelNumber; BOOL SensorPresent;
	double MinVoltage, MaxVoltage, Precision;
	double ShutdownTemperature;
	if (COM_AMP5_GetHardwareCapability (0,
		ChannelNumber, MinVoltage, MaxVoltage,
		Precision, SensorPresent, ShutdownTemperature))
		return Error (3); // handle a possible error

	// Get measured output voltages
	printf ("Measured output voltages:\n");
	for (WORD Channel = 0; Channel < ChannelNumber; Channel++)
		{
		double OutputVoltage;
		if (COM_AMP5_Get_OutputMonitor (0, Channel, OutputVoltage))
			return Error (4); // handle a possible error
		printf ("\tCh%hd: %+.3lfV\n", Channel, OutputVoltage);
		}

	// Get interlock state
	BOOL Closed;
	if (COM_AMP5_Get_InterlockState (0, Closed))
		return Error (5); // handle a possible error
	printf ("Interlock: %s\n", Closed ? "closed" : "open");

	// Get measured sensor current
	if (SensorPresent)
		{
		double SensorCurrent;
		if (COM_AMP5_Get_CurrentMonitor (0, SensorCurrent))
			return Error (6); // handle a possible error
		printf ("Current sensor: %+.3leA\n", SensorCurrent);
		}

	//finish the program:
	return 0;
	}

